Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.Person Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.Person einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.Person) | Gemeinde_Modelle.Person |
__str__(self) (Definiert in Gemeinde_Modelle.Person) | Gemeinde_Modelle.Person |
keyFeldNavi (Definiert in Gemeinde_Modelle.Person) | Gemeinde_Modelle.Person | static
R_anrede (Definiert in Gemeinde_Modelle.Person) | Gemeinde_Modelle.Person | static